@@ -24,11 +24,7 @@ class PhS3(object):
             Bucket=bk_name,
             Key=s3_path
         )
-        # return string.split(response["Body"].read().decode(), "\n")
-        try:
-            return str.split(response["Body"].read().decode(), "\n")
-        except TypeError:
-            return str.split(response["Body"].read().decode(encoding="utf-8"), "\n")
+        return string.split(response["Body"].read().decode(), "\n")
 
     def copy_object_2_file(self, bk_name, s3_path, local_path):
         f = open(local_path, "w")
